{% extends 'generic/object.html' %}
{% load render_table from django_tables2 %}

{% block content %}
<div class="row mb-3">
    <div class="col col-md-6">
        <div class="card">
            <h5 class="card-header">Control</h5>
            <div class="card-body">
                <table class="table table-hover attr-table">
                    <tr>
                        <th scope="row">Name</th>
                        <td>{{ object.name }}</td>
                    </tr>
                    <tr>
                        <th scope="row">Category</th>
                        <td>{{ object.category }}</td>
                    </tr>
                </table>
            </div>
        </div>
    </div>
    <div class="col col-md-6">
        <div class="card">
            <h5 class="card-header">Notes</h5>
            <div class="card-body">
              {{ object.notes | markdown  }}
            </div>
        </div> 
    </div>
</div>
<div class="row mb-3">
    <div class="col col-md-6">
        {% include 'inc/panels/comments.html' %}
        {% include 'inc/panels/custom_fields.html' %}
        {% include 'inc/panels/tags.html' %}
    </div>
           
</div>




{% endblock %}