{% extends 'generic/object.html' %}
{% load humanize %}
{% load helpers %}
{% load render_table from django_tables2 %}


{% block content %}
<div class="row mb-3">
    <div class="col col-md-6">
        <div class="card">
            <h5 class="card-header">Vulnerability</h5>
            <div class="card-body">
                <table class="table table-hover attr-table">
                    <tr>
                        <th scope="row">Name</th>
                        <td>{{ object.name }}</td>
                    </tr>
                    <tr>
                        <th scope="row">CVE</th>
                        <td>{{ object.cve }}</td>
                    </tr>
                    <tr>
                        <th scope="row">Description</th>
                        <td>{{ object.description }}</td>
                    </tr>
                </table>
            </div>
        </div>
        <div class="card">
          <h5 class="card-header">Notes</h5>
          <div class="card-body">
            {{ object.notes | markdown  }}
          </div>
        </div>        
    </div>
    <div class="col col-md-6">        
      <div class="card">
        <h5 class="card-header">CVSSv2 Score</h5>
        <div class="card-body">
          <table class="table table-hover attr-table">
            <tr>
              <th scope="row">Access Vector (AV)</th>
              <td>{{ object.cvssaccessVector }}</td>
            </tr>
            <tr>
              <th scope="row">Access Complexity (AC)</th>
              <td>{{ object.cvssaccessComplexity }}</td>
            </tr>
            <tr>
              <th scope="row">Authentication (Au)</th>
              <td>{{ object.cvssauthentication }}</td>
            </tr>
            <tr>
              <th scope="row">Confidentiality Impact (C)</th>
              <td>{{ object.cvssconfidentialityImpact }}</td>
            </tr>
            <tr>
              <th scope="row">Integrity Impact (I)</th>
              <td>{{ object.cvssintegrityImpact }}</td>
            </tr>
            <tr>
              <th scope="row">Availability Impact (A)</th>
              <td>{{ object.cvssavailabilityImpact }}</td>
            </tr>
            <tr>
              <th scope="row">Base Score</th>
              <td>{{ object.cvssbaseScore }}</td>
            </tr> 
          </table>
        </div>
      </div>
      {% include 'inc/panels/tags.html' %}
    </div>

</div>
{% endblock %}

